@@ -41,7 +41,7 @@ use DBI;
 
 use base 'NetSDS::Class::Abstract';
 
-use version; our $VERSION = '1.206';
+use version; our $VERSION = '1.300';
 
 #===============================================================================
 
@@ -251,8 +251,8 @@ sub fetch_call {
 
 Example:
 
-    $obj->add_sets("set search_path to myscheme");
-    $obj->add_sets("set client_encoding to 'UTF-8'");
+    $obj->_add_sets("set search_path to myscheme");
+    $obj->_add_sets("set client_encoding to 'UTF-8'");
 
 =cut
 
@@ -269,7 +269,7 @@ sub _add_sets {
 
 =item B<_add_attrs()> - add DBI handler attributes
 
-    $self->add_attrs(AutoCommit => 1);
+    $self->_add_attrs(AutoCommit => 1);
 
 =cut
 
@@ -334,7 +334,7 @@ sub _connect {
 		}
 
 	} else {
-		return $self->error( "Cant connect to DBMS: " . $DBI::errsts );
+		return $self->error( "Cant connect to DBMS: " . $DBI::errstr );
 	}
 
 } ## end sub _connect
@@ -349,22 +349,36 @@ __END__
 
 samples/testdb.pl
 
-=head1 BUGS
-
-Unknown yet
-
 =head1 SEE ALSO
 
-None
+L<DBI>, L<DBD::Pg>
 
 =head1 TODO
 
-None
+1. Make module less PostgreSQL specific.
 
 =head1 AUTHOR
 
 Michael Bochkaryov <misha@rattler.kiev.ua>
 
+=head1 LICENSE
+
+Copyright (C) 2008-2009 Net Style Ltd.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 =cut
 
 
